<?php

declare(strict_types=1);

namespace OpenTelemetry\SDK\Metrics\Exemplar;

use OpenTelemetry\Context\ContextInterface;
use OpenTelemetry\SDK\Common\Attribute\AttributesInterface;

/**
 * The exemplar spec is not yet stable, and can change at any time.
 * @see https://github.com/open-telemetry/opentelemetry-specification/blob/main/specification/metrics/sdk.md#exemplar
 */
interface ExemplarFilterInterface
{
    /**
     * @param float|int $value
     */
    public function accepts($value, AttributesInterface $attributes, ContextInterface $context, int $timestamp): bool;
}
