<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opentelemetry/proto/metrics/v1/metrics.proto

namespace Opentelemetry\Proto\Metrics\V1;

use UnexpectedValueException;

/**
 * DataPointFlags is defined as a protobuf 'uint32' type and is to be used as a
 * bit-field representing 32 distinct boolean flags.  Each flag defined in this
 * enum is a bit-mask.  To test the presence of a single flag in the flags of
 * a data point, for example, use an expression like:
 *   (point.flags & DATA_POINT_FLAGS_NO_RECORDED_VALUE_MASK) == DATA_POINT_FLAGS_NO_RECORDED_VALUE_MASK
 *
 * Protobuf type <code>opentelemetry.proto.metrics.v1.DataPointFlags</code>
 */
class DataPointFlags
{
    /**
     * The zero value for the enum. Should not be used for comparisons.
     * Instead use bitwise "and" with the appropriate mask as shown above.
     *
     * Generated from protobuf enum <code>DATA_POINT_FLAGS_DO_NOT_USE = 0;</code>
     */
    const DATA_POINT_FLAGS_DO_NOT_USE = 0;
    /**
     * This DataPoint is valid but has no recorded value.  This value
     * SHOULD be used to reflect explicitly missing data in a series, as
     * for an equivalent to the Prometheus "staleness marker".
     *
     * Generated from protobuf enum <code>DATA_POINT_FLAGS_NO_RECORDED_VALUE_MASK = 1;</code>
     */
    const DATA_POINT_FLAGS_NO_RECORDED_VALUE_MASK = 1;

    private static $valueToName = [
        self::DATA_POINT_FLAGS_DO_NOT_USE => 'DATA_POINT_FLAGS_DO_NOT_USE',
        self::DATA_POINT_FLAGS_NO_RECORDED_VALUE_MASK => 'DATA_POINT_FLAGS_NO_RECORDED_VALUE_MASK',
    ];

    public static function name($value)
    {
        if (!isset(self::$valueToName[$value])) {
            throw new UnexpectedValueException(sprintf(
                    'Enum %s has no name defined for value %s', __CLASS__, $value));
        }
        return self::$valueToName[$value];
    }


    public static function value($name)
    {
        $const = __CLASS__ . '::' . strtoupper($name);
        if (!defined($const)) {
            throw new UnexpectedValueException(sprintf(
                    'Enum %s has no value defined for name %s', __CLASS__, $name));
        }
        return constant($const);
    }
}

