<?php
/**
 * Class QRCodeOutputException
 *
 * @filesource   QRCodeOutputException.php
 * @created      09.12.2015
 * @package      chillerlan\QRCode\Output
 * @author       Smiley <smiley@chillerlan.net>
 * @copyright    2015 Smiley
 * @license      MIT
 */

namespace chillerlan\QRCode\Output;

use chillerlan\QRCode\QRCodeException;

class QRCodeOutputException extends QRCodeException{}
