<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opentelemetry/proto/metrics/v1/metrics.proto

namespace Opentelemetry\Proto\Metrics\V1;

if (false) {
    /**
     * This class is deprecated. Use Opentelemetry\Proto\Metrics\V1\ExponentialHistogramDataPoint\Buckets instead.
     * @deprecated
     */
    class ExponentialHistogramDataPoint_Buckets {}
}
class_exists(ExponentialHistogramDataPoint\Buckets::class);
@trigger_error('Opentelemetry\Proto\Metrics\V1\ExponentialHistogramDataPoint_Buckets is deprecated and will be removed in the next major release. Use Opentelemetry\Proto\Metrics\V1\ExponentialHistogramDataPoint\Buckets instead', E_USER_DEPRECATED);

