<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opentelemetry/proto/collector/logs/v1/logs_service.proto

namespace Opentelemetry\Proto\Collector\Logs\V1;

use Google\Protobuf\Internal\GPBType;
use Google\Protobuf\Internal\RepeatedField;
use Google\Protobuf\Internal\GPBUtil;

/**
 * Generated from protobuf message <code>opentelemetry.proto.collector.logs.v1.ExportLogsPartialSuccess</code>
 */
class ExportLogsPartialSuccess extends \Google\Protobuf\Internal\Message
{
    /**
     * The number of rejected log records.
     * A `rejected_<signal>` field holding a `0` value indicates that the
     * request was fully accepted.
     *
     * Generated from protobuf field <code>int64 rejected_log_records = 1;</code>
     */
    protected $rejected_log_records = 0;
    /**
     * A developer-facing human-readable message in English. It should be used
     * either to explain why the server rejected parts of the data during a partial
     * success or to convey warnings/suggestions during a full success. The message
     * should offer guidance on how users can address such issues.
     * error_message is an optional field. An error_message with an empty value
     * is equivalent to it not being set.
     *
     * Generated from protobuf field <code>string error_message = 2;</code>
     */
    protected $error_message = '';

    /**
     * Constructor.
     *
     * @param array $data {
     *     Optional. Data for populating the Message object.
     *
     *     @type int|string $rejected_log_records
     *           The number of rejected log records.
     *           A `rejected_<signal>` field holding a `0` value indicates that the
     *           request was fully accepted.
     *     @type string $error_message
     *           A developer-facing human-readable message in English. It should be used
     *           either to explain why the server rejected parts of the data during a partial
     *           success or to convey warnings/suggestions during a full success. The message
     *           should offer guidance on how users can address such issues.
     *           error_message is an optional field. An error_message with an empty value
     *           is equivalent to it not being set.
     * }
     */
    public function __construct($data = NULL) {
        \GPBMetadata\Opentelemetry\Proto\Collector\Logs\V1\LogsService::initOnce();
        parent::__construct($data);
    }

    /**
     * The number of rejected log records.
     * A `rejected_<signal>` field holding a `0` value indicates that the
     * request was fully accepted.
     *
     * Generated from protobuf field <code>int64 rejected_log_records = 1;</code>
     * @return int|string
     */
    public function getRejectedLogRecords()
    {
        return $this->rejected_log_records;
    }

    /**
     * The number of rejected log records.
     * A `rejected_<signal>` field holding a `0` value indicates that the
     * request was fully accepted.
     *
     * Generated from protobuf field <code>int64 rejected_log_records = 1;</code>
     * @param int|string $var
     * @return $this
     */
    public function setRejectedLogRecords($var)
    {
        GPBUtil::checkInt64($var);
        $this->rejected_log_records = $var;

        return $this;
    }

    /**
     * A developer-facing human-readable message in English. It should be used
     * either to explain why the server rejected parts of the data during a partial
     * success or to convey warnings/suggestions during a full success. The message
     * should offer guidance on how users can address such issues.
     * error_message is an optional field. An error_message with an empty value
     * is equivalent to it not being set.
     *
     * Generated from protobuf field <code>string error_message = 2;</code>
     * @return string
     */
    public function getErrorMessage()
    {
        return $this->error_message;
    }

    /**
     * A developer-facing human-readable message in English. It should be used
     * either to explain why the server rejected parts of the data during a partial
     * success or to convey warnings/suggestions during a full success. The message
     * should offer guidance on how users can address such issues.
     * error_message is an optional field. An error_message with an empty value
     * is equivalent to it not being set.
     *
     * Generated from protobuf field <code>string error_message = 2;</code>
     * @param string $var
     * @return $this
     */
    public function setErrorMessage($var)
    {
        GPBUtil::checkString($var, True);
        $this->error_message = $var;

        return $this;
    }

}

