<?php
class FeedEnclosure {
	/** @var string */
	public $link;

	/** @var string */
	public $type;

	/** @var string */
	public $length;

	/** @var string */
	public $title;

	/** @var string */
	public $height;

	/** @var string */
	public $width;
}

