<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opentelemetry/proto/collector/trace/v1/trace_service.proto

namespace Opentelemetry\Proto\Collector\Trace\V1;

use Google\Protobuf\Internal\GPBType;
use Google\Protobuf\Internal\RepeatedField;
use Google\Protobuf\Internal\GPBUtil;

/**
 * Generated from protobuf message <code>opentelemetry.proto.collector.trace.v1.ExportTraceServiceRequest</code>
 */
class ExportTraceServiceRequest extends \Google\Protobuf\Internal\Message
{
    /**
     * An array of ResourceSpans.
     * For data coming from a single resource this array will typically contain one
     * element. Intermediary nodes (such as OpenTelemetry Collector) that receive
     * data from multiple origins typically batch the data before forwarding further and
     * in that case this array will contain multiple elements.
     *
     * Generated from protobuf field <code>repeated .opentelemetry.proto.trace.v1.ResourceSpans resource_spans = 1;</code>
     */
    private $resource_spans;

    /**
     * Constructor.
     *
     * @param array $data {
     *     Optional. Data for populating the Message object.
     *
     *     @type \Opentelemetry\Proto\Trace\V1\ResourceSpans[]|\Google\Protobuf\Internal\RepeatedField $resource_spans
     *           An array of ResourceSpans.
     *           For data coming from a single resource this array will typically contain one
     *           element. Intermediary nodes (such as OpenTelemetry Collector) that receive
     *           data from multiple origins typically batch the data before forwarding further and
     *           in that case this array will contain multiple elements.
     * }
     */
    public function __construct($data = NULL) {
        \GPBMetadata\Opentelemetry\Proto\Collector\Trace\V1\TraceService::initOnce();
        parent::__construct($data);
    }

    /**
     * An array of ResourceSpans.
     * For data coming from a single resource this array will typically contain one
     * element. Intermediary nodes (such as OpenTelemetry Collector) that receive
     * data from multiple origins typically batch the data before forwarding further and
     * in that case this array will contain multiple elements.
     *
     * Generated from protobuf field <code>repeated .opentelemetry.proto.trace.v1.ResourceSpans resource_spans = 1;</code>
     * @return \Google\Protobuf\Internal\RepeatedField
     */
    public function getResourceSpans()
    {
        return $this->resource_spans;
    }

    /**
     * An array of ResourceSpans.
     * For data coming from a single resource this array will typically contain one
     * element. Intermediary nodes (such as OpenTelemetry Collector) that receive
     * data from multiple origins typically batch the data before forwarding further and
     * in that case this array will contain multiple elements.
     *
     * Generated from protobuf field <code>repeated .opentelemetry.proto.trace.v1.ResourceSpans resource_spans = 1;</code>
     * @param \Opentelemetry\Proto\Trace\V1\ResourceSpans[]|\Google\Protobuf\Internal\RepeatedField $var
     * @return $this
     */
    public function setResourceSpans($var)
    {
        $arr = GPBUtil::checkRepeatedField($var, \Google\Protobuf\Internal\GPBType::MESSAGE, \Opentelemetry\Proto\Trace\V1\ResourceSpans::class);
        $this->resource_spans = $arr;

        return $this;
    }

}

