/* line 3, main.scss */
html, body {
  background-color: #f9f9f9;
  border: 0;
  padding: 0;
  margin: 0;
  height: 100%;
  width: 100%;
  color: #444;
  font-family: RobotoDraft, Roboto, sans-serif;
  font-size: 14px;
  -webkit-font-smoothing: antialiased; }

/* line 16, main.scss */
*, *:before, *:after {
  -moz-box-sizing: border-box;
  -webkit-box-sizing: border-box;
  box-sizing: border-box; }

/* line 20, main.scss */
* {
  font-family: RobotoDraft, Roboto, sans-serif; }

/* line 24, main.scss */
a {
  color: #02a8f3;
  text-decoration: none; }
  /* line 27, main.scss */
  a:hover {
    text-decoration: underline; }
  /* line 30, main.scss */
  a, a:hover {
    outline: 0; }

/* line 35, main.scss */
#head-panel {
  background-color: #03a9f4;
  padding: 30px 0 20px; }
  /* line 38, main.scss */
  #head-panel h1 {
    color: #fff;
    font-size: 50px;
    font-weight: normal;
    margin: 0 0 10px 0;
    display: inline-block; }
    /* line 44, main.scss */
    #head-panel h1:after {
      letter-spacing: 0.5em;
      content: "\00a0"; }
  /* line 49, main.scss */
  #head-panel .buttons {
    display: inline-block;
    color: transparent; }

/* line 55, main.scss */
.container {
  width: 100%;
  padding: 0 20px;
  height: 100%; }

/* line 61, main.scss */
.wrap {
  min-height: 100%;
  height: auto;
  margin: 0 auto -120px;
  padding: 0 0 160px; }

/* line 68, main.scss */
.content {
  margin: 120px 0 40px; }
  /* line 70, main.scss */
  .content p {
    line-height: 36px;
    font-size: 20px;
    margin-top: 2px;
    margin-bottom: 10px; }
  /* line 76, main.scss */
  .content code {
    padding: 0;
    padding-top: 0.2em;
    padding-bottom: 0.2em;
    margin: 0;
    font-size: 85%;
    background-color: rgba(0, 0, 0, 0.04);
    border-radius: 3px; }
    /* line 84, main.scss */
    .content code:before, .content code:after {
      letter-spacing: -0.2em;
      content: "\00a0"; }

/* line 91, main.scss */
#search-panel {
  height: 64px;
  width: 100%;
  background-color: #ffffff;
  box-shadow: 0 0 2px rgba(0, 0, 0, 0.2);
  position: absolute;
  z-index: 7; }
  /* line 98, main.scss */
  #search-panel.top-fixed {
    position: fixed;
    top: 0;
    left: 0;
    right: 0;
    box-shadow: 0 4px 5px 0 rgba(0, 0, 0, 0.14), 0 1px 10px 0 rgba(0, 0, 0, 0.12), 0 2px 4px -1px rgba(0, 0, 0, 0.2); }
  /* line 105, main.scss */
  #search-panel .container {
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    -ms-flex-align: center;
    -webkit-align-items: center;
    align-items: center;
    height: 100%; }
  /* line 117, main.scss */
  #search-panel .search-icon {
    display: inline-block;
    vertical-align: middle;
    background-repeat: no-repeat;
    fill: currentcolor;
    position: relative;
    opacity: 0.5; }
    /* line 124, main.scss */
    #search-panel .search-icon, #search-panel .search-icon .mdi {
      height: 24px;
      width: 24px;
      font-size: 24px; }
    /* line 129, main.scss */
    #search-panel .search-icon.clear-icon {
      cursor: pointer; }
      /* line 131, main.scss */
      #search-panel .search-icon.clear-icon:hover {
        opacity: 1; }
  /* line 136, main.scss */
  #search-panel #search {
    color: #434343;
    font-size: 20px;
    margin-left: 16px;
    padding: 8px 0;
    width: auto;
    border: none;
    outline: none;
    -ms-flex: 1 1 0.000000001px;
    -webkit-flex: 1;
    flex: 1;
    -webkit-flex-basis: 0.000000001px;
    flex-basis: 0.000000001px; }

/* line 152, main.scss */
#grid-container {
  padding: 0 0 70px;
  min-height: 900px;
  margin-top: 67px; }
  /* line 156, main.scss */
  #grid-container .grid {
    margin: 20px -15px 0 -15px; }
    /* line 158, main.scss */
    #grid-container .grid:after {
      clear: both;
      display: table;
      content: " "; }
  /* line 164, main.scss */
  #grid-container:after {
    clear: both;
    display: table;
    content: " "; }
  /* line 169, main.scss */
  #grid-container h2 {
    color: #a2a2a2;
    font-size: 16px;
    font-weight: normal;
    display: block;
    border-top: 1px solid rgba(0, 0, 0, 0.08);
    padding: 67px 0 0;
    margin: 47px 0 10px; }
  /* line 178, main.scss */
  #grid-container .no-results {
    text-align: center;
    color: #909090;
    font-size: 24px;
    padding: 150px 0; }
  /* line 184, main.scss */
  #grid-container .item-container {
    display: block;
    width: 112px;
    height: 120px;
    margin: 0 10px 5px;
    padding: 20px 0 0;
    cursor: pointer;
    background: transparent;
    float: left;
    transition: background 200ms ease-out;
    border-radius: 2px; }
    /* line 195, main.scss */
    #grid-container .item-container:hover {
      background: #f2f2f2; }
    /* line 198, main.scss */
    #grid-container .item-container.selected {
      background: #e0e0e0; }
    /* line 201, main.scss */
    #grid-container .item-container .item {
      -ms-flex-align: center;
      -webkit-align-items: center;
      align-items: center;
      -ms-flex-direction: column;
      -webkit-flex-direction: column;
      flex-direction: column;
      display: -ms-flexbox;
      display: -webkit-flex;
      display: flex;
      position: relative; }
      /* line 212, main.scss */
      #grid-container .item-container .item .new-badge {
        position: absolute;
        right: 8px;
        top: -12px;
        padding: 2px 3px;
        border-radius: 2px;
        background: #fe6363;
        color: #fff;
        font-size: 10px;
        font-weight: 500; }
      /* line 223, main.scss */
      #grid-container .item-container .item .mdi {
        font-size: 48px;
        width: 48px;
        height: 48px;
        color: #757575; }
      /* line 229, main.scss */
      #grid-container .item-container .item .caption {
        color: #757575;
        font-size: 11px;
        margin-top: 16px;
        overflow: hidden;
        text-align: center;
        text-overflow: ellipsis;
        white-space: nowrap;
        width: 100px;
        z-index: 1; }

/* line 244, main.scss */
#snackbar {
  position: fixed;
  bottom: 0;
  left: 0;
  right: 0;
  z-index: 5; }
  /* line 250, main.scss */
  #snackbar .snackbar-header {
    color: #fff;
    height: 64px;
    background-color: #03a9f4;
    padding: 19px 20px 20px;
    line-height: 26px;
    overflow: hidden; }
    /* line 257, main.scss */
    #snackbar .snackbar-header .mdi {
      width: 24px;
      height: 24px;
      font-size: 24px;
      float: left; }
    /* line 263, main.scss */
    #snackbar .snackbar-header .caption {
      font-size: 16px;
      margin-left: 15px; }
    /* line 267, main.scss */
    #snackbar .snackbar-header .right-side {
      display: none;
      float: right; }
      /* line 270, main.scss */
      #snackbar .snackbar-header .right-side .mdi {
        font-size: 22px;
        margin-top: 1px; }
      /* line 274, main.scss */
      #snackbar .snackbar-header .right-side .caption {
        font-weight: 500;
        margin-left: 10px;
        text-transform: uppercase;
        font-size: 14px; }
  /* line 282, main.scss */
  #snackbar p, #snackbar p a, #snackbar .code {
    font-family: 'Roboto Mono', monospace;
    font-size: 13px;
    line-height: 24px;
    background-color: #eee; }
  /* line 288, main.scss */
  #snackbar .code {
    color: #434343;
    border: 0;
    cursor: default;
    display: block;
    outline: none;
    padding: 0;
    height: 24px;
    resize: none;
    width: 100%;
    white-space: nowrap;
    overflow: hidden; }
    /* line 300, main.scss */
    #snackbar .code.comment {
      opacity: 0.5; }
  /* line 304, main.scss */
  #snackbar .snackbar-content {
    background-color: #eee;
    padding: 8px 24px;
    overflow: hidden;
    -webkit-transition: -webkit-transform 200ms cubic-bezier(0.4, 0, 0.2, 1);
    transition: transform 200ms cubic-bezier(0.4, 0, 0.2, 1);
    box-shadow: 0 -2px 5px rgba(0, 0, 0, 0.1); }
    /* line 311, main.scss */
    #snackbar .snackbar-content h2, #snackbar .snackbar-content p {
      font-size: 13px;
      line-height: 24px;
      font-family: 'Roboto Mono', monospace; }
    /* line 316, main.scss */
    #snackbar .snackbar-content h2 {
      color: #02a8f3;
      display: inline-block;
      font-weight: 500;
      margin: 0; }
    /* line 322, main.scss */
    #snackbar .snackbar-content p {
      margin: 0;
      color: #434343; }
    /* line 326, main.scss */
    #snackbar .snackbar-content .col {
      margin: 16px 0; }
  /* line 330, main.scss */
  #snackbar .snackbar-header, #snackbar .snackbar-content {
    margin: 0 -20px 0; }

/* line 335, main.scss */
#footer {
  background: #EEE;
  padding: 20px 0;
  min-height: 120px; }

@media (min-width: 500px) {
  /* line 343, main.scss */
  #snackbar .snackbar-content .col {
    margin: 16px 40px 16px 0; }
  /* line 346, main.scss */
  #snackbar .snackbar-header .right-side {
    display: block; } }
@media (min-width: 800px) {
  /* line 353, main.scss */
  .flex {
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex; }

  /* line 361, main.scss */
  .col {
    width: 50%; }

  /* line 364, main.scss */
  .container {
    padding: 0 35px;
    margin: 0 auto; }

  /* line 368, main.scss */
  .snackbar-header, .snackbar-content {
    margin: 0 -10px 0; }

  /* line 371, main.scss */
  #grid-container .grid {
    margin: 20px -30px 0 -15px; } }
@media (min-width: 950px) {
  /* line 377, main.scss */
  .col {
    width: 45%; } }
@media (min-width: 1100px) {
  /* line 383, main.scss */
  .col {
    width: 40%; } }
@media (min-width: 1240px) {
  /* line 389, main.scss */
  .container {
    width: 1226px; } }
