<?php
/**
 * Class QRCodeDataException
 *
 * @filesource   QRCodeDataException.php
 * @created      09.12.2015
 * @package      chillerlan\QRCode\Data
 * @author       Smiley <smiley@chillerlan.net>
 * @copyright    2015 Smiley
 * @license      MIT
 */

namespace chillerlan\QRCode\Data;

use chillerlan\QRCode\QRCodeException;

class QRCodeDataException extends QRCodeException{}
